"use strict";
var JsonApiModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonApiModule = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const core_1 = require("@nestjs/core");
const swaggerUi = require("swagger-ui-express");
const swagger_service_1 = require("./services/swagger/swagger.service");
const constants_1 = require("./constants");
const mixins_1 = require("./mixins");
const constants_2 = require("@nestjs/swagger/dist/constants");
let JsonApiModule = JsonApiModule_1 = class JsonApiModule {
    constructor(moduleRef, adapterHost) {
        this.moduleRef = moduleRef;
        this.adapterHost = adapterHost;
    }
    onModuleInit() {
        swagger_service_1.SwaggerService.getEntities().forEach(async (entity) => {
            const repoName = JsonApiModule_1.connectionName === constants_1.DEFAULT_CONNECTION_NAME
                ? `${entity.name}Repository`
                : `${JsonApiModule_1.connectionName}_${entity.name}Repository`;
            const repository = this.moduleRef.get(repoName, { strict: false });
            swagger_service_1.SwaggerService.addResourceConfig(repository.metadata);
        });
        const config = swagger_service_1.SwaggerService.getConfig();
        if (!config.hideSwaggerRoute) {
            const document = swagger_service_1.SwaggerService.prepareDocument();
            const { httpAdapter } = this.adapterHost;
            const swaggerHtml = swaggerUi.generateHTML(document, {});
            httpAdapter.get(`/${config.prefix}`, (req, res) => res.send(swaggerHtml));
            httpAdapter.use(`/${config.prefix}`, swaggerUi.serveFiles(document, { swaggerOptions: {
                // oauth: {
                //   usePkceWithAuthorizationCodeGrant: true
                // }
                }
            }));
        }
    }
    static forRoot(options) {
        const { globalPrefix } = options;
        const optionsProviders = options.providers || [];
        const optionsImports = options.imports || [];
        JsonApiModule_1.connectionName =
            options.connectionName || JsonApiModule_1.connectionName;
        const moduleParams = {
            module: JsonApiModule_1,
            controllers: [],
            providers: [
                ...optionsProviders,
                {
                    provide: constants_1.JSON_API_CONFIG,
                    useValue: {
                        globalPrefix,
                    },
                },
            ],
            imports: [
                typeorm_1.TypeOrmModule.forFeature(options.entities, JsonApiModule_1.connectionName),
                ...optionsImports,
            ],
        };
        const swaggerOptions = options.swagger || {};
        swagger_service_1.SwaggerService.setConfig({
            ...swaggerOptions,
            apiPrefix: swaggerOptions.apiPrefix || globalPrefix,
        });
        const getCustomRoutes = (controller, entity) => {
            if (!controller ||
                !Reflect.hasOwnMetadata(constants_2.DECORATORS.API_TAGS, controller)) {
                return;
            }
            const methodNames = Object.getOwnPropertyNames(controller.prototype).filter((methodName) => Reflect.hasOwnMetadata(constants_2.DECORATORS.API_RESPONSE, controller.prototype[methodName]));
            const entityName = entity instanceof Function ? entity.name : entity.options.name;
            return methodNames.map((methodName) => {
                const path = Reflect.getMetadata('path', controller.prototype[methodName]);
                const method = Reflect.getMetadata('method', controller.prototype[methodName]);
                const response = Reflect.getMetadata(constants_2.DECORATORS.API_RESPONSE, controller.prototype[methodName]);
                const operation = Reflect.getMetadata(constants_2.DECORATORS.API_OPERATION, controller.prototype[methodName]);
                return { path, method, response, operation, entityName, methodName };
            });
        };
        options.entities.forEach((entity) => {
            const controller = (options.controllers || []).find((item) => Reflect.getMetadata(constants_1.JSON_API_ENTITY, item) === entity);
            const module = (0, mixins_1.moduleMixin)(globalPrefix, controller, entity, JsonApiModule_1.connectionName);
            moduleParams.controllers = [
                ...moduleParams.controllers,
                module.controller,
            ];
            moduleParams.providers = [...moduleParams.providers, ...module.providers];
            const customRoutes = getCustomRoutes(controller, entity);
            if (customRoutes) {
                swagger_service_1.SwaggerService.customRoutes.push(...customRoutes);
            }
            swagger_service_1.SwaggerService.addEntity(entity);
        });
        return moduleParams;
    }
};
JsonApiModule.connectionName = constants_1.DEFAULT_CONNECTION_NAME;
JsonApiModule = JsonApiModule_1 = (0, tslib_1.__decorate)([
    (0, common_1.Module)({}),
    (0, tslib_1.__metadata)("design:paramtypes", [core_1.ModuleRef,
        core_1.HttpAdapterHost])
], JsonApiModule);
exports.JsonApiModule = JsonApiModule;
//# sourceMappingURL=json-api.module.js.map