"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.interceptorMixin = void 0;
const tslib_1 = require("tslib");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const common_1 = require("@nestjs/common");
const mixin_1 = require("../../helpers/mixin");
const messages_1 = require("../../helpers/messages");
const types_1 = require("../../types");
function interceptorMixin() {
    let MixinInterceptor = class MixinInterceptor {
        async intercept(context, next) {
            return next.handle().pipe((0, operators_1.catchError)(error => {
                this.logger.error(error);
                if (Object.values(types_1.PostgresErrors).includes(error.code)) {
                    return (0, rxjs_1.throwError)(() => (0, messages_1.preparePostgresError)(context, error));
                }
                if (error instanceof common_1.HttpException) {
                    return (0, rxjs_1.throwError)(() => (0, messages_1.prepareHttpError)(context, error));
                }
                const preparedError = new common_1.HttpException({
                    errors: [{
                            detail: 'Internal server error',
                        }]
                }, 500);
                preparedError.stack = error.stack;
                return (0, rxjs_1.throwError)(() => preparedError);
            }));
        }
    };
    (0, tslib_1.__decorate)([
        (0, common_1.Inject)(common_1.Logger),
        (0, tslib_1.__metadata)("design:type", common_1.Logger)
    ], MixinInterceptor.prototype, "logger", void 0);
    MixinInterceptor = (0, tslib_1.__decorate)([
        (0, common_1.Injectable)()
    ], MixinInterceptor);
    return (0, mixin_1.mixin)(MixinInterceptor);
}
exports.interceptorMixin = interceptorMixin;
//# sourceMappingURL=interceptor.mixin.js.map