"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bodyDeleteRelationshipMixin = void 0;
const tslib_1 = require("tslib");
const typeorm_1 = require("@nestjs/typeorm");
const core_1 = require("@nestjs/core");
const common_1 = require("@nestjs/common");
const constants_1 = require("../../../constants");
const mixin_1 = require("../../../helpers/mixin");
const helpers_1 = require("../../../helpers");
function bodyDeleteRelationshipMixin(entity, connectionName) {
    let BodyDeleteRelationshipMixin = class BodyDeleteRelationshipMixin {
        async transform(value) {
            const bodyErrors = await (0, helpers_1.checkRelationBodyStructure)(value);
            if (bodyErrors.length > 0) {
                throw new common_1.UnprocessableEntityException(bodyErrors);
            }
            const relationNameParam = this.request.params[constants_1.PARAMS_RELATION_NAME];
            const relationMetadata = this.repository.metadata.relations.find(relation => relation.propertyName === relationNameParam);
            const generalErrors = [];
            generalErrors.push(...await (0, helpers_1.checkRelationDataBasicInfo)(value, relationMetadata));
            generalErrors.push(...await (0, helpers_1.checkRelationDataType)(value, relationMetadata));
            if (generalErrors.length > 0) {
                throw new common_1.UnprocessableEntityException(generalErrors);
            }
            return value;
        }
    };
    (0, tslib_1.__decorate)([
        (0, typeorm_1.InjectRepository)(entity, connectionName),
        (0, tslib_1.__metadata)("design:type", Object)
    ], BodyDeleteRelationshipMixin.prototype, "repository", void 0);
    (0, tslib_1.__decorate)([
        (0, common_1.Inject)(core_1.REQUEST),
        (0, tslib_1.__metadata)("design:type", Object)
    ], BodyDeleteRelationshipMixin.prototype, "request", void 0);
    BodyDeleteRelationshipMixin = (0, tslib_1.__decorate)([
        (0, common_1.Injectable)()
    ], BodyDeleteRelationshipMixin);
    return (0, mixin_1.mixin)(BodyDeleteRelationshipMixin);
}
exports.bodyDeleteRelationshipMixin = bodyDeleteRelationshipMixin;
//# sourceMappingURL=body-delete-relationship.js.map